@@ -8,9 +8,13 @@ package ex::lib;
 
 ex::lib - The same as C<lib>, but makes relative path absolute.
 
+=cut
+
+$ex::lib::VERSION = 0.05;
+
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =head1 SYNOPSIS
 
@@ -65,9 +69,7 @@ Mons Anderson, <mons@cpan.org>
 
 use strict;
 use lib ();
-use Cwd 3.29 qw(abs_path);
-$ex::lib::VERSION = 0.04;
-# TODO: check, fix, extend patterns
+use Cwd 3.12 qw(abs_path);
 $ex::lib::sep = {
 	( map { $_ => qr{[^\\/]+$}o } qw(mswin32 netware symbian dos) ),
 	( map { $_ => qr{[^:]+:?$}o } qw(macos) ),
@@ -75,8 +77,8 @@ $ex::lib::sep = {
 
 sub DEBUG () { 0 }; # use constants is heavy
 
-sub _carp  { require Carp; Carp::carp(@_)  }
-sub _croak { require Carp; Carp::croak(@_) }
+sub _carp  { require Carp; goto &Carp::carp  }
+sub _croak { require Carp; goto &Carp::croak }
 
 sub mkapath($) {
 	my $depth = shift;
@@ -93,7 +95,6 @@ sub mkapath($) {
 }
 
 sub transform {
-	local $@; # Don't poison $@
 	my $prefix;
 	map {
 		ref || m{^/} ? $_ : do {
@@ -110,7 +111,6 @@ sub transform {
 
 sub import {
 	shift;
-	local $@; # Don't poison $@
 	_croak("Bad usage. use ".__PACKAGE__." PATH") unless @_;
 	@_ = ( lib => transform @_ = @_ );
 	warn "use @_\n" if DEBUG > 0;
@@ -120,7 +120,6 @@ sub import {
 
 sub unimport {
 	shift;
-	local $@; # Don't poison $@
 	_croak("Bad usage. use ".__PACKAGE__." PATH") unless @_;
 	@_ = ( lib => transform @_ = @_ );
 	warn "no @_\n" if DEBUG > 0;
